@@ -1,8 +1,8 @@
 /*
  gc_computers.c - Functions for the Computers section
 
- Geek Code Generator v1.7 - Generates your geek code
- Copyright (C) 1999-2000 Chris Gushue <seymour@lazygenes.net>
+ Geek Code Generator v1.7.3 - Generates your geek code
+ Copyright (C) 1999-2003 Chris Gushue <chris@blackplasma.net>
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -73,7 +73,7 @@ int get_unix_type(void)
 	printf("UNIX Type                                                         Page %ia of %i\n", PAGES-(PAGES-7), PAGES);
 	printf("===============================================================================\n");
 	printf(" 1 B - BSD (use unless your BSDish system is mentioned below)\n");
-	printf(" 2 L - Linux\n");
+	printf(" 2 L - GNU/Linux\n");
 	printf(" 3 U - Ultrix\n");
 	printf(" 4 A - AIX\n");
 	printf(" 5 V - SysV\n");
@@ -212,7 +212,7 @@ int get_linux(void)
    do
      {
 	clearscreen();
-	printf("Linux                                                              Page %i of %i\n", PAGES-(PAGES-9), PAGES);
+	printf("GNU/Linux                                                          Page %i of %i\n", PAGES-(PAGES-9), PAGES);
 	printf("===============================================================================\n");
         printf("1 L+++++ I am Linus, grovel before me.\n");
         printf("2 L++++  I am a Linux wizard. I munch C code for breakfast and have enough room\n");
@@ -235,7 +235,7 @@ int get_linux(void)
         printf("\n");
         printf("\n");
         printf("\n");
-	printf("Enter your Linux code number here [0 to quit]: ");
+	printf("Enter your GNU/Linux code number here [0 to quit]: ");
 	scanf("%d", &selection);
 	clear_kb();
      } while (selection < 0 || selection > 9);
