@@ -1,8 +1,8 @@
 /*
  geekcode.c - Main program
 
- Geek Code Generator v1.7 - Generates your geek code
- Copyright (C) 1999-2000 Chris Gushue <seymour@lazygenes.net>
+ Geek Code Generator v1.7.3 - Generates your geek code
+ Copyright (C) 1999-2003 Chris Gushue <chris@blackplasma.net>
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -20,14 +20,88 @@
 */
 
 #include <stdio.h>
+#include <string.h>
+#include <sys/stat.h>
 #include "geekcode.h"
 
-int main()
+int readgeek(char geekcode[64][16],char *data,int *j,int *k){
+  int i;
+
+  for(i=0;i<strlen(data);i++){
+    if(data[i]==':'){geekcode[*j][*k]=0;(*j)++;geekcode[*j][0]=':';*k=1;} else
+    if(data[i]==' ' || data[i]=='\n'){
+      if(data[i+1]!=' ' && data[i+1]!='\n'){
+        geekcode[*j][*k]=0;(*j)++;*k=0;
+      }
+    }else{
+      geekcode[*j][*k]=data[i];
+      (*k)++;
+    }
+  }
+  return 0;
+}
+
+void read_code()
+{
+  char filename[256];
+  char error[284];
+  char data[1024];
+  char geekcode[64][16];
+  struct stat fileinfo;
+  FILE *gcfile;
+  int j=0,k=0;
+  
+  clearscreen();
+  printf("Enter filename with Geekcode signature: ");
+  if(fgets(filename,256,stdin) == NULL){
+    perror("Error while reading the filename");
+    exit(1);
+  }
+  filename[strlen(filename)-1]=0;
+  if(stat(filename,&fileinfo) == -1){
+    snprintf(error, sizeof error, "Error while checking file \"%s\"",filename);
+    perror(error);
+    exit(1);
+  }
+  if(S_ISREG(fileinfo.st_mode)!=1){
+    fprintf(stderr,"Error, file \"%s\" isn't a regular file\n",filename);
+    exit(1);
+  }
+  gcfile=fopen(filename,"r");
+  if(gcfile==NULL){
+    snprintf(error, sizeof error, "Error while opening file \"%s\"",filename);
+    perror(error);
+    exit(1);
+  }
+  if(fgets(data,1024,gcfile) == NULL){
+    snprintf(error, sizeof error, "Error while reading file \"%s\"",filename);
+    perror(error);
+    exit(1);
+  }
+  if(strcmp(data,"-----BEGIN GEEK CODE BLOCK-----\n")!=0){
+    fprintf(stderr,"Error, file \"%s\" isn't geekcode\n",filename);
+    exit(1);
+  }
+  if(fgets(data,1024,gcfile) == NULL){  //read version
+    fprintf(stderr,"Error, file \"%s\" isn't geekcode\n",filename);
+    exit(1);
+  }
+  while(1){
+    if(fgets(data,1024,gcfile) == NULL){
+      fprintf(stderr,"Error, file \"%s\" isn't geekcode\n",filename);
+      exit(1);
+    }
+    if(strcmp(data,"------END GEEK CODE BLOCK------\n") == 0) break;
+    if(readgeek(geekcode,data,&j,&k) != 0){
+      exit(1);
+    }  
+  }
+  fclose(gcfile);
+  translate(geekcode,j);
+}
+
+void create_code()
 {
-   clearscreen();
-   printf("Geek Code Generator v%s - Generates your geek code\n", VERSION);	/* Modified in v1.2 */
-   printf("Copyright (C) 1999 Chris Gushue <seymour@lazygenes.net>\n");
-   printf("\n");
 
    /* Geek Type */
    gc_type          = get_type();
@@ -80,7 +154,31 @@ int main()
 
    show_geekcode(gc_sex_type);                       /* Modified in v1.2 */
    write_geekcode(gc_sex_type);			     /* Added in v1.7 */
+}
 
+int main()
+{
+   int selection = 99;
+
+   clearscreen();
+   printf("Geek Code Generator v%s - Generates your geek code\n", VERSION);  /* Modified in v1.2 */
+   printf("Copyright (C) 1999-2003 Chris Gushue <chris@blackplasma.net>\n");
+   printf("\n");
+   do{
+    printf("1) Create your own Geekcode\n");
+    printf("2) Read a Geekcode\n");
+    printf("\n");
+    printf("Enter your choise here [0 to quit]: ");
+    scanf("%d", &selection);
+    clear_kb();
+   }while(selection<0 || selection>2);
+   switch(selection){
+    case 1:
+     create_code();
+     break;
+    case 2:
+     read_code();
+   }
    return 0;
 }
 
@@ -96,7 +194,7 @@ void show_geekcode(int x)
 
    clearscreen();
    printf("Geek Code Generator v%s - Generates your geek code\n", VERSION);	/* Modified in v1.2 */
-   printf("Copyright (C) 1999 Chris Gushue <seymour@lazygenes.net>\n");
+   printf("Copyright (C) 1999-2003 Chris Gushue <chris@blackplasma.net>\n");
    printf("\n");
    printf("This is free software; see the source for copying conditions.  There is NO\n");
    printf("warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE,\n");
