@@ -1,8 +1,8 @@
 /*
  geekcode.h - GeekCode Global Header File
 
- Geek Code Generator v1.7 - Generates your geek code
- Copyright (C) 1999-2000 Chris Gushue <seymour@lazygenes.net>
+ Geek Code Generator v1.7.3 - Generates your geek code
+ Copyright (C) 1999-2003 Chris Gushue <chris@blackplasma.net>
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
 #define __INCLUDED_GEEKCODE_H__
 
 
-#define VERSION "1.7" /* Added in v1.2 */
+#define VERSION "1.7.3" /* Added in v1.2 */
 
 #define PAGES 35 /* Page counter: using formula PAGE = PAGES-(PAGES-PAGE)
                     where the second PAGE is the number of the page
@@ -91,5 +91,7 @@ void clear_kb(void);                      /* Added in v1.3 */
 /* Console I/O - gc_consoleio.c */
 void clearscreen();
 
+/* geekcode -> English - gc_translate.c */
+void translate(char geekcode[64][16], int j);
 
 #endif /* __INCLUDED_GEEKCODE_H__ */
